@@ -47,6 +47,9 @@ typedef unsigned char uchar;
 typedef unsigned short ushort;
 typedef unsigned int uint;
 typedef unsigned long int ulong;
+#define IPESEP ('\\')
+#else
+#define IPESEP ('/')
 #endif
 
 #undef assert
@@ -74,7 +77,7 @@ namespace ipe {
 
   //! Ipelib version.
   /*! \ingroup base */
-  const int IPELIB_VERSION = 70108;
+  const int IPELIB_VERSION = 70109;
 
   //! Oldest readable file format version.
   /*! \ingroup base */
@@ -336,8 +339,10 @@ namespace ipe {
   public:
     typedef void (*DebugHandler)(const char *);
 
+#ifdef IPEBUNDLE
+    static String ipeDir(const char *suffix, const char *fname = 0);
+#endif
 #ifdef WIN32
-    static String ipeDir(const char *suffix);
     static String winConv(const String &utf8, const String &encoding);
     static String wideToUtf8(const wchar_t *wbuf);
     static void utf8ToWide(const char *utf8, std::vector<wchar_t> &wbuf);
@@ -351,7 +356,6 @@ namespace ipe {
     static int libVersion();
     static void initLib(int version);
     static void setDebug(bool debug);
-    static char pathSeparator();
     static String currentDirectory();
     static String latexDirectory();
     static String fontmapFile();
