@@ -608,6 +608,8 @@ void AppUiBase::setGridAngleSize(Attribute abs_grid, Attribute abs_angle)
 {
   AttributeSeq seq;
   iCascade->allNames(EGridSize, seq);
+  if (!seq.size())
+    setComboCurrent(EUiGridSize, 0);
   for (uint i = 0; i < seq.size(); ++i) {
     if (iCascade->find(EGridSize, seq[i]) == abs_grid) {
       setComboCurrent(EUiGridSize, i);
@@ -616,6 +618,8 @@ void AppUiBase::setGridAngleSize(Attribute abs_grid, Attribute abs_angle)
   }
   seq.clear();
   iCascade->allNames(EAngleSize, seq);
+  if (!seq.size())
+    setComboCurrent(EUiAngleSize, 0);
   for (uint i = 0; i < seq.size(); ++i) {
     if (iCascade->find(EAngleSize, seq[i]) == abs_angle) {
       setComboCurrent(EUiAngleSize, i);
