@@ -255,7 +255,7 @@ Qt::DockWidgetArea getDockSide(lua_State *L, const char *name,
 
 extern void qt_set_sequence_auto_mnemonic(bool b);
 
-AppUi::AppUi(lua_State *L0, int model, Qt::WFlags f)
+AppUi::AppUi(lua_State *L0, int model, Qt::WindowFlags f)
   : QMainWindow(0, f), AppUiBase(L0, model)
 {
   setWindowIcon(prefsIcon("ipe"));
