@@ -1387,8 +1387,10 @@ LRESULT CALLBACK AppUi::wndProc(HWND hwnd, UINT message, WPARAM wParam,
     }
     case NM_RCLICK:
       if (ui) {
-	int l = ((LPNMITEMACTIVATE) lParam)->iItem;
-	if (l >= 0) {
+	LPNMITEMACTIVATE nm = (LPNMITEMACTIVATE) lParam;
+	HWND from = nm->hdr.hwndFrom;
+	int l = nm->iItem;
+	if (from == ui->hLayers && l >= 0) {
 	  POINT pos = ((LPNMITEMACTIVATE) lParam)->ptAction;
 	  ClientToScreen(ui->hLayers, &pos);
 	  Vector v(pos.x, pos.y);
