@@ -311,11 +311,10 @@ function MODEL:showLayerBoxPopup(v, layer)
   local p = self:page()
   local m = ipeui.Menu(self.ui:win())
   local active = p:active(self.vno)
-  if p:visible(self.vno, layer) then
-    m:add("invisible", "Make " .. layer .. " invisible in view " .. self.vno)
-  else
-    m:add("visible", "Make " .. layer .. " visible in view " .. self.vno)
-  end
+  m:add("visible", "Make " .. layer .. " visible from view "
+	.. self.vno .. " onwards")
+  m:add("invisible", "Make " .. layer .. " invisible from view "
+	.. self.vno .. " onwards")
   m:add("rename", "Rename " .. layer)
   m:add("delete", "Delete " .. layer)
   if layer ~= active then
@@ -357,9 +356,11 @@ function MODEL:layeraction_make_visible(layer, arg, vis)
   local p = self:page()
   local label
   if vis then
-    label = "make layer " .. layer .. " visible in view " .. self.vno
+    label = "make layer " .. layer .. " visible from view "
+      .. self.vno .. " onwards"
   else
-    label = "make layer " .. layer .. " invisible in view " .. self.vno
+    label = "make layer " .. layer .. " invisible from view "
+      .. self.vno .. " onwards"
   end
   local t = { label=label,
 	      pno=self.pno,
@@ -495,7 +496,8 @@ end
 
 function MODEL:layeraction_rename(layer)
   local p = self:page()
-  local name = self:getString("Enter new name for layer '" .. layer .. "'")
+  local name = self:getString("Enter new name for layer '" .. layer .. "'",
+			      nil, layer)
   if not name then return end
   name = string.gsub(name, "%s+", "_")
   if indexOf(name, p:layers()) then
@@ -766,12 +768,16 @@ end
 
 function MODEL:action_about_ipelets()
   local s = ""
-  for _,v in ipairs(ipelets) do
+  for i,v in ipairs(ipelets) do
     if v.label then
-      s = s .. " * " .. v.label .. "\n   " .. v.about .. "\n"
+      s = s .. "### " .. v.label .. " ###\n\n" .. v.about .. "\n"
     end
   end
-  messageBox(self.ui:win(), "information", "About the ipelets", s)
+  local d = ipeui.Dialog(self.ui:win(), "Ipe: About the ipelets")
+  d:add("text", "text", { read_only=true }, 1, 1)
+  d:set("text", s)
+  d:addButton("ok", "Ok", "accept")
+  d:execute(prefs.latexlog_size)
 end
 
 function MODEL:action_keyboard()
@@ -1968,7 +1974,7 @@ end
 
 function MODEL:action_update_style_sheets()
   local dir = nil
-  if self.file_name then dir = string.gsub(self.file_name, "[^/]+$", "") end
+  if self.file_name then dir = string.gsub(self.file_name, "[^/\\]+$", "") end
   if dir == "" then dir = "." end
   local sheets = self.doc:sheets()
   local qlog = ""
