@@ -150,11 +150,11 @@ function transformShape(matrix, shape)
 end
 
 function findStyle(w, dir)
-  if dir and ipe.fileExists(dir .. "/" .. w) then
-    return dir .. "/" .. w
+  if dir and ipe.fileExists(dir .. prefs.fsep .. w) then
+    return dir .. prefs.fsep .. w
   end
   for _, d in ipairs(config.styleDirs) do
-    local s = d .. "/" .. w
+    local s = d .. prefs.fsep .. w
     if ipe.fileExists(s) then return s end
   end
 end
@@ -239,7 +239,7 @@ function win32_shortcut_convert(s)
       done = true
     end
   end
-  if s:sub(1,1) == "F" and tonumber(s:sub(2)) then
+  if s ~= "F" and s:sub(1,1) == "F" and tonumber(s:sub(2)) then
     return k + 0x6f + tonumber(s:sub(2))
   elseif win32_conversions[s] then
     return k + win32_conversions[s]
@@ -336,12 +336,12 @@ else
   if config.platform == "win" then
     local userdir = os.getenv("USERPROFILE")
     if userdir then
-      table.insert(config.ipeletDirs, 1, userdir .. "\\Ipelets")
+      config.ipeletDirs[#config.ipeletDirs + 1] = userdir .. "\\Ipelets"
     end
   else
-    table.insert(config.ipeletDirs, 1, home .. "/.ipe/ipelets")
+    config.ipeletDirs[#config.ipeletDirs + 1] = home .. "/.ipe/ipelets"
     if config.platform == "apple" then
-      table.insert(config.ipeletDirs, 2, home .. "/Library/Ipe/Ipelets")
+      config.ipeletDirs[#config.ipeletDirs + 1] = home.."/Library/Ipe/Ipelets"
     end
   end
 end
@@ -380,8 +380,8 @@ for _,w in ipairs(config.ipeletDirs) do
       if f:sub(-4) == ".lua" then
 	ft = {}
 	ft.name = f:sub(1,-5)
-	ft.path = w .. "/" .. f
-	ft.dllname = w .. "/" .. ft.name
+	ft.path = w .. prefs.fsep .. f
+	ft.dllname = w .. prefs.fsep .. ft.name
 	ft._G = _G
 	ft.ipe = ipe
 	ft.ipeui = ipeui
@@ -440,7 +440,7 @@ if #style_sheets > 0 then prefs.styles = style_sheets end
 config.styleList = {}
 for _,w in ipairs(prefs.styles) do
   if w:sub(-4) ~= ".isy" then w = w .. ".isy" end
-  if not w:find("/") then w = findStyle(w) end
+  if not w:find(prefs.fsep) then w = findStyle(w) end
   config.styleList[#config.styleList + 1] = w
 end
 
