@@ -246,9 +246,11 @@ end
 -- Pattern for lists of filenames
 -- The separator is a semicolon on Windows, a colon otherwise
 if config.platform == "win" then
+  prefs.fsep = "\\"
   prefs.fname_pattern = "[^;]+"
   prefs.basename_pattern = "\\([^\\]+)$"
 else
+  prefs.fsep = "/"
   prefs.fname_pattern = "[^:]+"
   prefs.basename_pattern = "/([^/]+)$"
 end
