@@ -190,7 +190,7 @@ static int appui_setSnap(lua_State *L)
   lua_pop(L, 1);
   lua_getfield(L, -1, "gridsize");
   if (!lua_isnil(L, -1))
-    snap.iGridSize = luaL_checkint(L, -1);
+    snap.iGridSize = (int)luaL_checkinteger(L, -1);
   lua_pop(L, 1);
   lua_getfield(L, -1, "anglesize");
   if (!lua_isnil(L, -1))
@@ -198,7 +198,7 @@ static int appui_setSnap(lua_State *L)
   lua_pop(L, 1);
   lua_getfield(L, -1, "snap_distance");
   if (!lua_isnil(L, -1))
-    snap.iSnapDistance = luaL_checkint(L, -1);
+    snap.iSnapDistance = (int)luaL_checkinteger(L, -1);
   lua_pop(L, 1);
   lua_getfield(L, -1, "with_axes");
   if (!lua_isnil(L, -1))
@@ -375,7 +375,7 @@ static int shapetool_setshape(lua_State *L)
   Shape shape = check_shape(L, 1);
   int which = 0;
   if (!lua_isnoneornil(L, 2))
-    which = luaL_checkint(L, 2);
+    which = (int)luaL_checkinteger(L, 2);
   double pen = 1.0;
   if (lua_isnumber(L, 3))
     pen = luaL_checknumber(L, 3);
