@@ -153,6 +153,10 @@ int Bitmap::init(const XmlAttributes &attr)
 }
 
 //! Create a new image
+/*! \a filter specifies the format of the \a data.
+  If \a filter is EDirect, then setting \a deflate
+  compresses the bitmap and changes the filter to EFlateDecode.
+ */
 Bitmap::Bitmap(int width, int height,
 	       TColorSpace colorSpace, int bitsPerComponent,
 	       Buffer data, TFilter filter, bool deflate)
@@ -714,13 +718,14 @@ Bitmap Bitmap::readJpeg(const char *fname, Vector &dotsPerInch,
 
 //! Read PNG image from file.
 /*! Returns the image as a Bitmap.
+  It will be compressed if \a deflate is set.
   Sets \a dotsPerInch if the image file contains a resolution,
   otherwise sets it to (0,0).
   If reading the file fails, returns a null Bitmap,
   and sets the error message \a errmsg.
 */
-Bitmap Bitmap::readPNG(const char *fname, Vector &dotsPerInch,
-		       const char * &errmsg)
+Bitmap Bitmap::readPNG(const char *fname, bool deflate,
+		       Vector &dotsPerInch, const char * &errmsg)
 {
   FILE *fp = Platform::fopen(fname, "rb");
   if (!fp) {
@@ -773,8 +778,30 @@ Bitmap Bitmap::readPNG(const char *fname, Vector &dotsPerInch,
     samples = 1;
   }
 
-  if (color_type == PNG_COLOR_TYPE_PALETTE)
+  bool hasColorKey = false;
+  int colorKey = 0;
+
+  if (color_type == PNG_COLOR_TYPE_PALETTE) {
+    png_bytep trans_alpha = 0;
+    int num_trans = 0;
+    png_color_16p trans_color = 0;
+
+    png_get_tRNS(png_ptr, info_ptr, &trans_alpha, &num_trans, &trans_color);
+    if (num_trans == 1 && trans_alpha[0] == 0) {
+      // exactly one fully transparent color at index 0
+      int num_palette = 0;
+      png_colorp p = 0;
+      png_get_PLTE(png_ptr, info_ptr, &p, &num_palette);
+      if (num_palette > 0) {
+	hasColorKey = true;
+	colorKey = (p[0].red << 16) | (p[0].green << 8) | p[0].blue;
+      }
+    }
+
     png_set_palette_to_rgb(png_ptr);
+    if (trans_alpha)
+      png_set_strip_alpha(png_ptr);
+  }
 
   if (color_type & PNG_COLOR_MASK_ALPHA)
     png_set_strip_alpha(png_ptr);
@@ -803,7 +830,7 @@ Bitmap Bitmap::readPNG(const char *fname, Vector &dotsPerInch,
 		       mpi * png_get_y_pixels_per_meter(png_ptr, info_ptr));
 
   color_type = png_get_color_type(png_ptr, info_ptr);
-  ipeDebug("Depth %d, color type %d", depth, color_type);
+  ipeDebug("Depth %d, color type %d, samples %d", depth, color_type, samples);
 
   // get data
   Buffer pixels(width * height * samples);
@@ -815,7 +842,10 @@ Bitmap Bitmap::readPNG(const char *fname, Vector &dotsPerInch,
   png_read_end(png_ptr, (png_infop) NULL);
   png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp) NULL);
   fclose(fp);
-  return Bitmap(width, height, cs, depth, pixels, Bitmap::EDirect, false);
+  Bitmap bm(width, height, cs, depth, pixels, Bitmap::EDirect, deflate);
+  if (hasColorKey)
+    bm.setColorKey(colorKey);
+  return bm;
 }
 
 // --------------------------------------------------------------------
