@@ -140,7 +140,7 @@ static int document_tostring(lua_State *L)
 
 static int check_pageno(lua_State *L, int i, Document *d, int extra = 0)
 {
-  int n = luaL_checkint(L, i);
+  int n = (int)luaL_checkinteger(L, i);
   luaL_argcheck(L, 1 <= n && n <= d->countPages() + extra, i,
 		"invalid page number");
   return n - 1;
@@ -172,7 +172,7 @@ static int document_len(lua_State *L)
 static int document_page_iterator(lua_State *L)
 {
   Document **d = check_document(L, 1);
-  int i = luaL_checkint(L, 2);
+  int i = (int)luaL_checkinteger(L, 2);
   i = i + 1;
   if (i <= (*d)->countPages()) {
     lua_pushnumber(L, i);               // new counter
@@ -593,7 +593,7 @@ static int ipe_readImage(lua_State *L)
 
   Bitmap bmp = fmt ?
     Bitmap::readJpeg(s.z(), dotsPerInch, errmsg) :
-    Bitmap::readPNG(s.z(), dotsPerInch, errmsg);
+    Bitmap::readPNG(s.z(), true, dotsPerInch, errmsg);
 
   if (bmp.isNull()) {
     lua_pushnil(L);
