@@ -41,7 +41,7 @@ public:
   virtual bool buildAndRun(int w, int h);
   virtual void retrieveValues();
   virtual void enableItem(int idx, bool value);
-  virtual void accept(lua_State *L);
+  virtual void acceptDialog(lua_State *L);
 private:
   static void setListBoxRow(GtkTreeView *w, int row);
   static GtkWidget *createListBox(const SElement &m);
@@ -63,7 +63,7 @@ PDialog::~PDialog()
   //
 }
 
-void PDialog::accept(lua_State *L)
+void PDialog::acceptDialog(lua_State *L)
 {
   int accept = lua_toboolean(L, 2);
   (void) accept; // TODO
@@ -455,8 +455,8 @@ PMenu::~PMenu()
 
 int PMenu::execute(lua_State *L)
 {
-  iPopupX = luaL_checkint(L, 2);
-  iPopupY = luaL_checkint(L, 3);
+  iPopupX = (int)luaL_checkinteger(L, 2);
+  iPopupY = (int)luaL_checkinteger(L, 3);
   iSelectedItem = -1;
   gtk_menu_popup(GTK_MENU(iMenu), NULL, NULL,
 		 // GtkMenuPositionFunc(positionResponse), this,
@@ -697,7 +697,7 @@ static int ipeui_messageBox(lua_State *L)
     details = luaL_checkstring(L, 4);
   int buttons = 0;
   if (lua_isnumber(L, 5))
-    buttons = luaL_checkint(L, 5);
+    buttons = (int)luaL_checkinteger(L, 5);
   else if (!lua_isnoneornil(L, 5))
     buttons = luaL_checkoption(L, 5, 0, buttontype);
 
@@ -824,7 +824,7 @@ gboolean PTimer::elapsed()
 // does not update interval on running timer
 int PTimer::setInterval(lua_State *L)
 {
-  int t = luaL_checkint(L, 2);
+  int t = (int)luaL_checkinteger(L, 2);
   iInterval = t;
   return 0;
 }
