@@ -417,7 +417,7 @@ void PDialog::enableItem(int idx, bool value)
   iWidgets[idx]->setEnabled(value);
 }
 
-void PDialog::accept(lua_State *L)
+void PDialog::acceptDialog(lua_State *L)
 {
   int accept = lua_toboolean(L, 2);
   QDialog::done(accept);
@@ -465,8 +465,8 @@ PMenu::~PMenu()
 
 int PMenu::execute(lua_State *L)
 {
-  int vx = luaL_checkint(L, 2);
-  int vy = luaL_checkint(L, 3);
+  int vx = (int)luaL_checkinteger(L, 2);
+  int vy = (int)luaL_checkinteger(L, 3);
   QAction *a = iMenu->exec(QPoint(vx, vy));
   MenuAction *ma = qobject_cast<MenuAction *>(a);
   if (ma) {
@@ -657,7 +657,7 @@ void PTimer::elapsed()
 
 int PTimer::setInterval(lua_State *L)
 {
-  int t = luaL_checkint(L, 2);
+  int t = (int)luaL_checkinteger(L, 2);
   iTimer->setInterval(t);
   return 0;
 }
@@ -772,7 +772,7 @@ static int ipeui_fileDialog(lua_State *L)
   }
 
   if (selected)
-    dialog.selectFilter(filters[selected-1]);
+    dialog.selectNameFilter(filters[selected-1]);
   if (!dir.isNull())
     dialog.setDirectory(dir);
   if (!name.isNull())
@@ -812,7 +812,7 @@ static int ipeui_messageBox(lua_State *L)
     details = luaL_checkstring(L, 4);
   int buttons = 0;
   if (lua_isnumber(L, 5))
-    buttons = luaL_checkint(L, 5);
+    buttons = (int)luaL_checkinteger(L, 5);
   else if (!lua_isnoneornil(L, 5))
     buttons = luaL_checkoption(L, 5, 0, buttontype);
 
