@@ -683,8 +683,8 @@ PMenu::~PMenu()
 
 int PMenu::execute(lua_State *L)
 {
-  int vx = luaL_checkint(L, 2);
-  int vy = luaL_checkint(L, 3);
+  int vx = (int)luaL_checkinteger(L, 2);
+  int vy = (int)luaL_checkinteger(L, 3);
   int result = TrackPopupMenu(hMenu,
 			      TPM_NONOTIFY | TPM_RETURNCMD | TPM_RIGHTBUTTON,
 			      vx, vy, 0, hwnd, NULL);
@@ -878,7 +878,7 @@ void PTimer::elapsed()
 
 int PTimer::setInterval(lua_State *L)
 {
-  int t = luaL_checkint(L, 2);
+  int t = (int)luaL_checkinteger(L, 2);
   iInterval = t;
   if (iTimer)
     SetTimer(NULL, iTimer, iInterval, TimerProc);
@@ -1054,7 +1054,7 @@ static int ipeui_messageBox(lua_State *L)
     details = luaL_checkstring(L, 4);
   int buttons = 0;
   if (lua_isnumber(L, 5))
-    buttons = luaL_checkint(L, 5);
+    buttons = (int)luaL_checkinteger(L, 5);
   else if (!lua_isnoneornil(L, 5))
     buttons = luaL_checkoption(L, 5, 0, buttontype);
 
