@@ -3,7 +3,7 @@
 # Updated by Nathaniel Cunningham, May 2014.
 
 # ========= Update the following items for your build ==========
-IPE_VERSION=7.1.8
+IPE_VERSION=7.1.9
 BUILD_YEAR=2015     ## For copyright info
 # ==============================================================
 
@@ -33,20 +33,8 @@ cp ipe/Info.plist $APPDIR/Contents/Info.plist
 
 # ipe startup script
 echo '#! /bin/bash
-
-# IPELATEXDIR
-# IPEFONTMAP
-# IPEDEBUG
-# IPESTYLES
-# IPELETPATH
-# IPEICONDIR
-# IPEDOCDIR
-# IPELUAPATH
-# EDITOR
-
 DIR="$( cd "$( dirname "$0" )" && cd .. && pwd )"/Resources/local/bin
-PATH=$DIR:/usr/texbin:/usr/local/texbin:/usr/local/bin:$PATH
-
+PATH=$DIR:/Library/TeX/texbin:/usr/texbin:/usr/local/texbin:/usr/local/bin:$PATH
 (cd "$DIR"; ./ipe)
 ' > $APPDIR/Contents/MacOS/ipe
 chmod +x $APPDIR/Contents/MacOS/ipe
